import 'package:flutter/material.dart';

 const double I_ICON_OFF = -3;
 const double I_ICON_ON = 0;
 const double I_TEXT_OFF = 3;
 const double I_TEXT_ON = 1;
 const double I_ALPHA_OFF = 0;
 const double I_ALPHA_ON = 1;
 const int I_ANIM_DURATION = 300;

class IndzoomTabItem extends StatelessWidget {
  IndzoomTabItem(
      {@required this.uniqueKey,
        @required this.selected,
        @required this.iconData,
        @required this.title,
        @required this.titleSize,
        @required this.callbackFunction,
        @required this.textColor,
        @required this.iconColor});

  final UniqueKey uniqueKey;
  final String title;
  final IconData iconData;
  final bool selected;
  final double titleSize;
  final Function(UniqueKey uniqueKey) callbackFunction;
  final Color textColor;
  final Color iconColor;

  final double iconYAlign = I_ICON_ON;
  final double textYAlign = I_TEXT_OFF;
  final double iconAlpha = I_ALPHA_ON;

  @override
  Widget build(BuildContext context) {
    return Expanded(
      child: Stack(
        fit: StackFit.expand,
        children: [
          Container(
            height: double.infinity,
            width: double.infinity,
            child: AnimatedAlign(
                duration: Duration(milliseconds: I_ANIM_DURATION),
                alignment: Alignment(0, I_TEXT_ON),
                child: Padding(
                  padding: (selected) ? EdgeInsets.all(8.0) : EdgeInsets.only(top: 10),
                  child: Text(
                    title,
                    overflow: TextOverflow.ellipsis,
                    maxLines: 1,
                    style: TextStyle(
                        fontWeight: FontWeight.w500,
                        fontSize: (selected) ? titleSize : titleSize - 2,
                        color: textColor
                    ),
                  ),
                )),
          ),
          Container(
            height: double.infinity,
            width: double.infinity,
            child: AnimatedAlign(
              duration: Duration(milliseconds: I_ANIM_DURATION),
              curve: Curves.easeIn,
              alignment: Alignment(0, (selected) ? I_ICON_OFF : I_ICON_ON),
              child: AnimatedOpacity(
                duration: Duration(milliseconds: I_ANIM_DURATION),
                opacity: (selected) ? I_ALPHA_OFF : I_ALPHA_ON,
                child: IconButton(
                  highlightColor: Colors.transparent,
                  splashColor: Colors.transparent,
                  padding: EdgeInsets.zero,
                  alignment: Alignment(0, 0),
                  icon: Icon(
                    iconData,
                    color: iconColor,
                    size: titleSize * 2.5,
                  ),
                  onPressed: () {
                    callbackFunction(uniqueKey);
                  },
                ),
              ),
            ),
          )
        ],
      ),
    );
  }
}




